

Instrument
================

.. currentmodule:: poppy

.. autoclass:: Instrument
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~Instrument.filter
      ~Instrument.filter_list
      ~Instrument.name
      ~Instrument.options
      ~Instrument.pixelscale
      ~Instrument.pupil
      ~Instrument.pupilopd

   
   

   
   

   .. rubric:: Methods Summary

   .. autosummary::
   
      ~Instrument.calcPSF
      ~Instrument.display

   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: filter
   .. autoattribute:: filter_list
   .. autoattribute:: name
   .. autoattribute:: options
   .. autoattribute:: pixelscale
   .. autoattribute:: pupil
   .. autoattribute:: pupilopd

   
   

   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: calcPSF
   .. automethod:: display

   
   